Struct dicom_core::dictionary::DataDictionaryEntryBuf
source · pub struct DataDictionaryEntryBuf {
pub tag: TagRange,
pub alias: String,
pub vr: VR,
}Expand description
A data type for a dictionary entry with full ownership.
Fields
tag: TagRangeThe attribute tag range
alias: StringThe alias of the attribute, with no spaces, usually InCapitalizedCamelCase
vr: VRThe typical value representation of the attribute