Struct dicom_core::dictionary::DictionaryEntryBuf
source · Expand description
A data type for a dictionary entry with full ownership.
Fields
tag: TagRangeThe attribute tag range
alias: StringThe alias of the attribute, with no spaces, usually InCapitalizedCamelCase
vr: VRThe typical value representation of the attribute