Struct dicom_core::dictionary::DictionaryEntryRef
source · [−]Expand description
A data type for a dictionary entry with a string slice for its alias.
Fields
tag: TagRangeThe attribute tag or tag range
alias: &'a strThe alias of the attribute, with no spaces, usually InCapitalizedCamelCase
vr: VRThe typical value representation of the attribute