pub trait DataDictionary: Debug {
    type Entry: DictionaryEntry;

    fn by_name(&self, name: &str) -> Option<&Self::Entry>;
    fn by_tag(&self, tag: Tag) -> Option<&Self::Entry>;
}
Type trait for a dictionary of DICOM attributes. Attribute dictionaries provide the means to convert a tag to an alias and vice versa, as well as a form of retrieving additional information about the attribute.

The methods herein have no generic parameters, so as to enable being used as a trait object.

Required Associated Types

The type of the dictionary entry.

Required Methods

Fetch an entry by its usual alias (e.g. “PatientName” or “SOPInstanceUID”). Aliases are usually case sensitive and not separated by spaces.

Fetch an entry by its tag.

Implementations on Foreign Types

Implementors