DataDictionaryEntry

Trait DataDictionaryEntry 

pub trait DataDictionaryEntry {
    // Required methods
    fn tag_range(&self) -> TagRange;
    fn alias(&self) -> &str;
    fn vr(&self) -> VirtualVr;

    // Provided method
    fn tag(&self) -> Tag { ... }
}
The data element dictionary entry type, representing a DICOM attribute.

Required Methods

fn tag_range(&self) -> TagRange

The full possible tag range of the attribute, which this dictionary entry can represent.

fn alias(&self) -> &str

The alias of the attribute, with no spaces, usually in UpperCamelCase.

fn vr(&self) -> VirtualVr

The extended value representation descriptor of the attribute. The use of VirtualVr is to attend to edge cases in which the representation of a value depends on surrounding context.

Provided Methods

fn tag(&self) -> Tag

Fetch a single tag applicable to this attribute.

Note that this is not necessarily the original tag used as key for this entry.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors