pub trait DictionaryEntry {
    fn tag_range(&self) -> TagRange;
    fn alias(&self) -> &str;
    fn vr(&self) -> VR;

    fn tag(&self) -> Tag { ... }
}
The dictionary entry data type, representing a DICOM attribute.

Required Methods

The full possible tag range of this attribute.

The alias of the attribute, with no spaces, usually in UpperCamelCase.

The typical value representation of the attribute. In some edge cases, an element might not have this VR.

Provided Methods

The attribute single tag.

Implementors