[−][src]Enum dicom_core::header::VR
An enum type for a DICOM value representation.
Variants
AEApplication Entity
ASAge String
ATAttribute Tag
CSCode String
DADate
DSDecimal String
DTDate Time
FLFloating Point Single
FDFloating Point Double
ISInteger String
LOLong String
LTLong Text
OBOther Byte
ODOther Double
OFOther Float
OLOther Long
OVOther Very Long
OWOther Word
PNPerson Name
SHShort String
SLSigned Long
SQSequence of Items
SSSigned Short
STShort Text
SVTime
TMSigned Very Long
UCUnlimited Characters
UIUnique Identifier (UID)
ULUnsigned Long
UNUnknown
URUniversal Resource Identifier or Universal Resource Locator (URI/URL)
USUnsigned Short
UTUnlimited Text
UVUnsigned Very Long
Methods
impl VR[src]
pub fn from_binary(chars: [u8; 2]) -> Option<Self>[src]
Obtain the value representation corresponding to the given two bytes. Each byte should represent an alphabetic character in upper case.
pub fn to_string(self) -> &'static str[src]
Retrieve a string representation of this VR.
pub fn to_bytes(self) -> [u8; 2][src]
Retrieve a copy of this VR's byte representation. The function returns two alphabetic characters in upper case.