Header

Trait Header 

pub trait Header: HasLength {
    // Required method
    fn tag(&self) -> Tag;

    // Provided methods
    fn is_item(&self) -> bool { ... }
    fn is_item_delimiter(&self) -> bool { ... }
    fn is_sequence_delimiter(&self) -> bool { ... }
    fn is_encapsulated_pixeldata(&self) -> bool { ... }
}
A trait for a data type containing a DICOM header.

Required Methods

fn tag(&self) -> Tag

Retrieve the element’s tag as a (group, element) tuple.

Provided Methods

fn is_item(&self) -> bool

Check whether this is the header of an item.

fn is_item_delimiter(&self) -> bool

Check whether this is the header of an item delimiter.

fn is_sequence_delimiter(&self) -> bool

Check whether this is the header of a sequence delimiter.

fn is_encapsulated_pixeldata(&self) -> bool

Check whether this is the header of an encapsulated pixel data.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors