Enum dicom_core::value::InvalidValueReadError
source · [−]#[non_exhaustive]
pub enum InvalidValueReadError {
Show 15 variants
NonPrimitiveType {
backtrace: Backtrace,
},
DateTimeZone {
backtrace: Backtrace,
},
ParseFloat {
backtrace: Backtrace,
source: ParseFloatError,
},
ParseInteger {
backtrace: Backtrace,
source: ParseIntError,
},
UnexpectedEndOfElement {},
NarrowConvert {
value: String,
backtrace: Backtrace,
},
ParseDate {
source: Error,
},
ParseTime {
source: Error,
},
ParseDateTime {
source: Error,
},
IntoDicomDate {
source: Error,
},
IntoDicomTime {
source: Error,
},
IntoDicomDateTime {
source: Error,
},
ParseDateRange {
source: Error,
},
ParseTimeRange {
source: Error,
},
ParseDateTimeRange {
source: Error,
},
}Expand description
Triggered when a value reading attempt fails.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonPrimitiveType
Fields
backtrace: BacktraceAttempted to retrieve a complex value as primitive.
DateTimeZone
Fields
backtrace: BacktraceInvalid or ambiguous combination of date with time.
ParseFloat
The value cannot be parsed to a floating point number.
ParseInteger
The value cannot be parsed to an integer.
UnexpectedEndOfElement
Fields
An attempt of reading more than the number of bytes in the length attribute was made.
NarrowConvert
The value cannot be converted to the target type requested.
ParseDate
Fields
source: ErrorParseTime
Fields
source: ErrorParseDateTime
Fields
source: ErrorIntoDicomDate
Fields
source: ErrorIntoDicomTime
Fields
source: ErrorIntoDicomDateTime
Fields
source: ErrorParseDateRange
Fields
source: ErrorParseTimeRange
Fields
source: ErrorParseDateTimeRange
Fields
source: ErrorTrait Implementations
sourceimpl Debug for InvalidValueReadError
impl Debug for InvalidValueReadError
sourceimpl Display for InvalidValueReadError
impl Display for InvalidValueReadError
sourceimpl Error for InvalidValueReadErrorwhere
Self: Debug + Display,
impl Error for InvalidValueReadErrorwhere
Self: Debug + Display,
sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
sourcefn cause(&self) -> Option<&dyn Error>
fn cause(&self) -> Option<&dyn Error>
👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
sourceimpl ErrorCompat for InvalidValueReadError
impl ErrorCompat for InvalidValueReadError
sourcefn iter_chain(&self) -> ChainCompat<'_>where
Self: AsErrorSource,
fn iter_chain(&self) -> ChainCompat<'_>where
Self: AsErrorSource,
Returns an iterator for traversing the chain of errors,
starting with the current error
and continuing with recursive calls to
Error::source. Read moreAuto Trait Implementations
impl RefUnwindSafe for InvalidValueReadError
impl Send for InvalidValueReadError
impl Sync for InvalidValueReadError
impl Unpin for InvalidValueReadError
impl UnwindSafe for InvalidValueReadError