[−][src]Enum dicom_core::value::Value
Representation of a full DICOM value, which may be either primitive or another DICOM object.
Variants
Primitive(PrimitiveValue)Primitive value
SequenceA complex sequence of items
Fields of Sequence
Methods
impl<I> Value<I> where
I: DicomValueType, [src]
I: DicomValueType,
pub fn multiplicity(&self) -> u32[src]
Obtain the number of individual values. In a sequence item, this is the number of items.
pub fn primitive(&self) -> Option<&PrimitiveValue>[src]
Gets a reference to the primitive value.
pub fn item(&self) -> Option<&[I]>[src]
Gets a reference to the items.
pub fn into_primitive(self) -> Option<PrimitiveValue>[src]
Retrieves the primitive value.
pub fn into_item(self) -> Option<C<I>>[src]
Retrieves the items.
pub fn to_str(&self) -> Result<Cow<str>, CastValueError>[src]
Retrieves the primitive value as a single string.
If the value contains multiple strings, they are concatenated
(separated by '\\') into an owned string.
pub fn as_u8(&self) -> Result<&[u8], CastValueError>[src]
Retrieves the primitive value as a sequence of unsigned bytes.
pub fn as_i32(&self) -> Result<&[i32], CastValueError>[src]
Retrieves the primitive value as a sequence of signed 32-bit integers.
pub fn to_tag(&self) -> Result<Tag, CastValueError>[src]
Retrieves the primitive value as a DICOM tag.
pub fn as_tags(&self) -> Result<&[Tag], CastValueError>[src]
Retrieves the primitive value as a sequence of DICOM tags.