pub struct DicomTime(_);Expand description
Represents a Dicom Time value with a partial precision, where some time components may be missing.
Unlike Ruts’s chrono::NaiveTime, this implemenation has only 6 digit precision
for fraction of a second.
DicomTime implements AsRange trait, enabling to retrieve specific
chrono::NaiveTime values.
Example
use chrono::NaiveTime;
use dicom_core::value::{DicomTime, AsRange};
let time = DicomTime::from_hm(12, 30)?;
assert_eq!(
time.latest()?,
NaiveTime::from_hms_micro(12, 30, 59, 999_999)
);
let milli = DicomTime::from_hms_milli(12, 30, 59, 123)?;
// value still not precise to microsecond
assert_eq!(milli.is_precise(), false);
assert_eq!(milli.to_string(), "12:30:59.123");
// for convenience, is precise enough to be retrieved as a NaiveTime
assert_eq!(
milli.to_naive_time()?,
NaiveTime::from_hms_micro(12, 30, 59, 123_000)
);
let time = DicomTime::try_from(&NaiveTime::from_hms(12, 30, 59))?;
// conversion from chrono value leads to a precise value
assert_eq!(time.is_precise(), true);
Implementations
sourceimpl DicomTime
impl DicomTime
sourcepub fn from_h(hour: u8) -> Result<DicomTime, Error>
pub fn from_h(hour: u8) -> Result<DicomTime, Error>
Constructs a new DicomTime with hour precision
(HH).
sourcepub fn from_hm(hour: u8, minute: u8) -> Result<DicomTime, Error>
pub fn from_hm(hour: u8, minute: u8) -> Result<DicomTime, Error>
Constructs a new DicomTime with hour and minute precision
(HHMM).
sourcepub fn from_hms(hour: u8, minute: u8, second: u8) -> Result<DicomTime, Error>
pub fn from_hms(hour: u8, minute: u8, second: u8) -> Result<DicomTime, Error>
Constructs a new DicomTime with hour, minute and second precision
(HHMMSS).
sourcepub fn from_hms_milli(
hour: u8,
minute: u8,
second: u8,
millisecond: u32
) -> Result<DicomTime, Error>
pub fn from_hms_milli(
hour: u8,
minute: u8,
second: u8,
millisecond: u32
) -> Result<DicomTime, Error>
Constructs a new DicomTime from an hour, minute, second and millisecond value,
which leads to a (HHMMSS.FFF) precision. Millisecond cannot exceed 999.
sourceimpl DicomTime
impl DicomTime
sourcepub fn to_encoded(&self) -> String
pub fn to_encoded(&self) -> String
Retrieves a dicom encoded string representation of the value.