Handling of date, time, date-time ranges. Needed for range matching. Parsing into ranges happens via partial precision structures (DicomDate, DicomTime, DicomDatime) so ranges can handle null components in date, time, date-time values.

Structs

Represents a date range as two Option<chrono::NaiveDate> values. None means no upper or no lower bound for range is present.
Represents a date-time range as two Option<chrono::DateTime<FixedOffset>> values. None means no upper or no lower bound for range is present.
Represents a time range as two Option<chrono::NaiveTime> values. None means no upper or no lower bound for range is present.

Enums

Traits

The DICOM protocol accepts date / time values with null components. Imprecise values are to be handled as date / time ranges. This trait is implemented by date / time structures with partial precision. If the date / time structure is not precise, it is up to the user to call one of these methods to retrieve a suitable chrono value.

Functions

Looks for a range separator ‘-’. Returns a DateRange.
Looks for a range separator ‘-’. Returns a DateTimeRange. Users are advised, that for very specific inputs, inconsistent behavior can occur. This behavior can only be produced when all of the following is true:
Looks for a range separator ‘-’. Returns a TimeRange.