DateTimeRange

Enum DateTimeRange 

pub enum DateTimeRange {
    Naive {
        start: Option<NaiveDateTime>,
        end: Option<NaiveDateTime>,
    },
    TimeZone {
        start: Option<DateTime<FixedOffset>>,
        end: Option<DateTime<FixedOffset>>,
    },
}
Represents a date-time range, that can either be time-zone naive or time-zone aware. It is stored as two Option<chrono::DateTime<FixedOffset>> or two Option<chrono::NaiveDateTime> values. None means no upper or no lower bound for range is present.

Example

use chrono::{NaiveDate, NaiveTime, NaiveDateTime, DateTime, FixedOffset, TimeZone};
use dicom_core::value::DateTimeRange;

let offset = FixedOffset::west_opt(3600).unwrap();

let dtr = DateTimeRange::from_start_to_end_with_time_zone(
    offset.from_local_datetime(&NaiveDateTime::new(
        NaiveDate::from_ymd_opt(2000, 5, 6).unwrap(),
        NaiveTime::from_hms_opt(15, 0, 0).unwrap()
    )).unwrap(),
    offset.from_local_datetime(&NaiveDateTime::new(
        NaiveDate::from_ymd_opt(2000, 5, 6).unwrap(),
        NaiveTime::from_hms_opt(16, 30, 0).unwrap()
    )).unwrap()
)?;

assert!(dtr.start().is_some());
assert!(dtr.end().is_some());

Variants



Naive

DateTime range without time-zone information



TimeZone

DateTime range with time-zone information

Implementations

Source

impl DateTimeRange

pub fn from_start_to_end_with_time_zone( start: DateTime<FixedOffset>, end: DateTime<FixedOffset>, ) -> Result<DateTimeRange, Error>

Constructs a new time-zone aware DateTimeRange from two chrono::DateTime<FixedOffset> values monotonically ordered in time.

pub fn from_start_to_end( start: NaiveDateTime, end: NaiveDateTime, ) -> Result<DateTimeRange, Error>

Constructs a new time-zone naive DateTimeRange from two chrono::NaiveDateTime values monotonically ordered in time.

pub fn from_start_with_time_zone(start: DateTime<FixedOffset>) -> DateTimeRange

Constructs a new time-zone aware DateTimeRange beginning with a chrono::DateTime<FixedOffset> value and no upper limit.

pub fn from_start(start: NaiveDateTime) -> DateTimeRange

Constructs a new time-zone naive DateTimeRange beginning with a chrono::NaiveDateTime value and no upper limit.

pub fn from_end_with_time_zone(end: DateTime<FixedOffset>) -> DateTimeRange

Constructs a new time-zone aware DateTimeRange with no lower limit, ending with a chrono::DateTime<FixedOffset> value.

pub fn from_end(end: NaiveDateTime) -> DateTimeRange

Constructs a new time-zone naive DateTimeRange with no lower limit, ending with a chrono::NaiveDateTime value.

pub fn start(&self) -> Option<PreciseDateTime>

Returns the lower bound of the range, if present.

pub fn end(&self) -> Option<PreciseDateTime>

Returns the upper bound of the range, if present.

pub fn from_date_and_time_range( dr: DateRange, tr: TimeRange, ) -> Result<DateTimeRange, Error>

For combined datetime range matching, this method constructs a DateTimeRange from a DateRange and a TimeRange. As ‘DateRange’ and ‘TimeRange’ are always time-zone unaware, the resulting DateTimeRange will always be time-zone unaware.