Struct dicom_core::value::range::DateTimeRange
source · [−]pub struct DateTimeRange { /* private fields */ }Expand description
Represents a date-time range as two Option<chrono::DateTime<FixedOffset>> values.
None means no upper or no lower bound for range is present.
Example
use chrono::{DateTime, FixedOffset, TimeZone};
use dicom_core::value::DateTimeRange;
let offset = FixedOffset::west(3600);
let dtr = DateTimeRange::from_start_to_end(
offset.ymd(2000, 5, 6).and_hms(15, 0, 0),
offset.ymd(2000, 5, 6).and_hms(16, 30, 0)
)?;
assert!(dtr.start().is_some());
assert!(dtr.end().is_some());Implementations
sourceimpl DateTimeRange
impl DateTimeRange
sourcepub fn from_start_to_end(
start: DateTime<FixedOffset>,
end: DateTime<FixedOffset>
) -> Result<DateTimeRange, Error>
pub fn from_start_to_end(
start: DateTime<FixedOffset>,
end: DateTime<FixedOffset>
) -> Result<DateTimeRange, Error>
Constructs a new DateTimeRange from two chrono::DateTime values
monotonically ordered in time.
sourcepub fn from_start(start: DateTime<FixedOffset>) -> DateTimeRange
pub fn from_start(start: DateTime<FixedOffset>) -> DateTimeRange
Constructs a new DateTimeRange beginning with a chrono::DateTime value
and no upper limit.
sourcepub fn from_end(end: DateTime<FixedOffset>) -> DateTimeRange
pub fn from_end(end: DateTime<FixedOffset>) -> DateTimeRange
Constructs a new DateTimeRange with no lower limit, ending with a chrono::DateTime value.
sourcepub fn start(&self) -> Option<&DateTime<FixedOffset>>
pub fn start(&self) -> Option<&DateTime<FixedOffset>>
Returns a reference to the lower bound of the range.
sourcepub fn end(&self) -> Option<&DateTime<FixedOffset>>
pub fn end(&self) -> Option<&DateTime<FixedOffset>>
Returns a reference to the upper bound of the range.
sourcepub fn from_date_and_time_range(
dr: DateRange,
tr: TimeRange,
offset: FixedOffset
) -> Result<DateTimeRange, Error>
pub fn from_date_and_time_range(
dr: DateRange,
tr: TimeRange,
offset: FixedOffset
) -> Result<DateTimeRange, Error>
For combined datetime range matching,
this method constructs a DateTimeRange from a DateRange and a TimeRange.