Function dicom_core::value::serialize::encode_date
source · [−]Expand description
Encode a single date in accordance to the DICOM Date (DA) value representation.
Encode a single date in accordance to the DICOM Date (DA) value representation.