Struct dicom_core::value::ConvertValueError
source · [−]pub struct ConvertValueError {
pub requested: &'static str,
pub original: ValueType,
pub cause: Option<InvalidValueReadError>,
}Expand description
An error type for a failed attempt at converting a value into another representation.
Fields
requested: &'static strThe value format requested
original: ValueTypeThe value’s original representation
cause: Option<InvalidValueReadError>The reason why the conversion was unsuccessful, or none if a conversion from the given original representation is not possible