Trait dicom_core::dictionary::DataDictionary
source · [−]pub trait DataDictionary: Debug {
type Entry: DictionaryEntry;
fn by_name(&self, name: &str) -> Option<&Self::Entry>;
fn by_tag(&self, tag: Tag) -> Option<&Self::Entry>;
}Expand description
Type trait for a dictionary of DICOM attributes. Attribute dictionaries provide the means to convert a tag to an alias and vice versa, as well as a form of retrieving additional information about the attribute.
The methods herein have no generic parameters, so as to enable being used as a trait object.
Required Associated Types
sourcetype Entry: DictionaryEntry
type Entry: DictionaryEntry
The type of the dictionary entry.