pub trait DataDictionaryEntry {
    // Required methods
    fn tag_range(&self) -> TagRange;
    fn alias(&self) -> &str;
    fn vr(&self) -> VR;

    // Provided method
    fn tag(&self) -> Tag { ... }
}
The data element dictionary entry type, representing a DICOM attribute.

Required Methods

source

fn tag_range(&self) -> TagRange

The full possible tag range of the atribute, which this dictionary entry can represent.

source

fn alias(&self) -> &str

The alias of the attribute, with no spaces, usually in UpperCamelCase.

source

fn vr(&self) -> VR

The typical value representation of the attribute. In some edge cases, an element might not have this VR.

Provided Methods

source

fn tag(&self) -> Tag

Fetch a single tag applicable to this attribute.

Note that this is not necessarily the original tag used as key for this entry.

Implementors