Struct dicom_core::header::DataElementHeader
source · [−]Expand description
A data structure for a data element header, containing a tag, value representation and specified length.
Fields
tag: TagDICOM tag
vr: VRValue Representation
len: LengthElement length
Implementations
sourceimpl DataElementHeader
impl DataElementHeader
sourcepub fn new<T: Into<Tag>>(tag: T, vr: VR, len: Length) -> DataElementHeader
pub fn new<T: Into<Tag>>(tag: T, vr: VR, len: Length) -> DataElementHeader
Create a new data element header with the given properties. This is just a trivial constructor.
sourcepub fn is_non_primitive(&self) -> bool
pub fn is_non_primitive(&self) -> bool
Check whether the header suggests the value to be a sequence value: if the value representation is SQ or the length is undefined.